MCMC
====

.. currentmodule:: naima

- MCMC sampling
    - `naima.get_sampler`
    - `naima.run_sampler`
- Priors
    - `naima.normal_prior`
    - `naima.uniform_prior`
- Plotting and analysis
    - `naima.plot_chain`
    - `naima.plot_fit`
    - `naima.plot_blob`
    - `naima.save_diagnostic_plots`
    - `naima.save_results_table`
    
API
---

.. autofunction:: get_sampler
.. autofunction:: run_sampler
.. autofunction:: normal_prior
.. autofunction:: uniform_prior
.. autofunction:: plot_chain
.. autofunction:: plot_fit
.. autofunction:: plot_data
.. autofunction:: plot_blob
.. autofunction:: save_diagnostic_plots
.. autofunction:: save_results_table

